@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 
@@ -23,6 +23,11 @@
 #define __GST_TAG_TAG_H__
 
 #include <gst/gst.h>
+#include <gst/tag/tag-prelude.h>
+#include <gst/tag/gsttagdemux.h>
+#include <gst/tag/gsttagmux.h>
+#include <gst/tag/xmpwriter.h>
+#include <gst/tag/tag-enumtypes.h>
 
 G_BEGIN_DECLS
 
@@ -52,6 +57,22 @@ G_BEGIN_DECLS
  * MusicBrainz album artist ID
  */
 #define GST_TAG_MUSICBRAINZ_ALBUMARTISTID	"musicbrainz-albumartistid"
+/**
+ * GST_TAG_MUSICBRAINZ_RELEASEGROUPID:
+ *
+ * MusicBrainz Release Group ID
+ *
+ * Since: 1.18
+ */
+#define GST_TAG_MUSICBRAINZ_RELEASEGROUPID	"musicbrainz-releasegroupid"
+/**
+ * GST_TAG_MUSICBRAINZ_RELEASETRACKID:
+ *
+ * MusicBrainz Release Track ID
+ *
+ * Since: 1.18
+ */
+#define GST_TAG_MUSICBRAINZ_RELEASETRACKID	"musicbrainz-releasetrackid"
 /**
  * GST_TAG_MUSICBRAINZ_TRMID:
  *
@@ -59,6 +80,29 @@ G_BEGIN_DECLS
  */
 #define GST_TAG_MUSICBRAINZ_TRMID	"musicbrainz-trmid"
 
+/**
+ * GST_TAG_ACOUSTID_ID:
+ *
+ * AcoustID Identifier
+ * 
+ * Since: 1.18
+ */
+#define GST_TAG_ACOUSTID_ID	"acoustid-id"
+
+/**
+ * GST_TAG_ACOUSTID_FINGERPRINT:
+ *
+ * AcoustID Fingerprint (Chromaprint)
+ *
+ * Since: 1.18
+ */
+/*
+ * FIXME 2.0: Using "chromaprint-fingerprint" for backwards compatibility with the
+ * old custom tag from the chromaprint plugin but should change this to
+ * "acoustid-fingerprint" in 2.0 for consistency.
+*/
+#define GST_TAG_ACOUSTID_FINGERPRINT	"chromaprint-fingerprint"
+
 /**
  * GST_TAG_CMML_STREAM:
  *
@@ -78,6 +122,21 @@ G_BEGIN_DECLS
  * Annodex CMML clip element tag
  */
 #define GST_TAG_CMML_CLIP "cmml-clip"
+/**
+ * GST_TAG_MUSICAL_KEY:
+ *
+ * Musical key in which the sound starts. It is represented as a string
+ * with a maximum length of three characters. The ground keys are
+ * represented with "A","B","C","D","E", "F" and "G" and halfkeys
+ * represented with "b" and "#". Minor is represented as "m" (e.g. "Dbm").
+ * Off key is represented with an "o" only.
+ * This notation might be extended in the future to support non-minor/major
+ * keys.
+ *
+ * Since: 1.2
+ */
+#define GST_TAG_MUSICAL_KEY                   "musical-key"
+
 
 /* CDDA tags */
 
@@ -133,6 +192,15 @@ G_BEGIN_DECLS
  */
 #define GST_TAG_CAPTURING_FOCAL_LENGTH         "capturing-focal-length"
 
+/**
+ * GST_TAG_CAPTURING_FOCAL_LENGTH_35_MM:
+ *
+ * 35 mm equivalent focal length used when capturing an image, in mm. (double)
+ *
+ * Since: 1.10
+ */
+#define GST_TAG_CAPTURING_FOCAL_LENGTH_35_MM   "capturing-focal-length-35mm"
+
 /**
  * GST_TAG_CAPTURING_DIGITAL_ZOOM_RATIO:
  *
@@ -385,9 +453,6 @@ typedef enum {
   GST_TAG_IMAGE_TYPE_PUBLISHER_STUDIO_LOGO
 } GstTagImageType;
 
-#define GST_TYPE_TAG_IMAGE_TYPE  (gst_tag_image_type_get_type ())
-GType   gst_tag_image_type_get_type (void);
-
 /**
  * GST_TAG_ID3V2_HEADER_SIZE:
  *
@@ -398,25 +463,37 @@ GType   gst_tag_image_type_get_type (void);
 
 /* functions for vorbis comment manipulation */
 
+GST_TAG_API
 const gchar *           gst_tag_from_vorbis_tag                 (const gchar *          vorbis_tag);
+
+GST_TAG_API
 const gchar *           gst_tag_to_vorbis_tag                   (const gchar *          gst_tag);
+
+GST_TAG_API
 void                    gst_vorbis_tag_add                      (GstTagList *           list, 
                                                                  const gchar *          tag, 
                                                                  const gchar *          value);
 
+GST_TAG_API
 GList *                 gst_tag_to_vorbis_comments              (const GstTagList *     list, 
                                                                  const gchar *          tag);
 
 /* functions to convert GstBuffers with vorbiscomment contents to GstTagLists and back */
+
+GST_TAG_API
 GstTagList *            gst_tag_list_from_vorbiscomment         (const guint8 *         data,
                                                                  gsize                  size,
                                                                  const guint8 *         id_data,
                                                                  const guint            id_data_length,
                                                                  gchar **               vendor_string);
+
+GST_TAG_API
 GstTagList *            gst_tag_list_from_vorbiscomment_buffer  (GstBuffer *            buffer,
                                                                  const guint8 *         id_data,
                                                                  const guint            id_data_length,
                                                                  gchar **               vendor_string);
+
+GST_TAG_API
 GstBuffer *             gst_tag_list_to_vorbiscomment_buffer    (const GstTagList *     list,
                                                                  const guint8 *         id_data,
                                                                  const guint            id_data_length,
@@ -428,77 +505,112 @@ GstBuffer *             gst_tag_list_to_vorbiscomment_buffer    (const GstTagLis
  * gst_tag_list_from_id3v2_tag(). Also, note gst.tag.list_xyz() namespace vs. gst.tag_list_xyz(),
  * which is a bit confusing and possibly doesn't map too well */
 
+GST_TAG_API
 guint                   gst_tag_id3_genre_count                 (void);
+
+GST_TAG_API
 const gchar *           gst_tag_id3_genre_get                   (const guint            id);
+
+GST_TAG_API
 GstTagList *            gst_tag_list_new_from_id3v1             (const guint8 *         data);
 
+GST_TAG_API
 const gchar *           gst_tag_from_id3_tag                    (const gchar *          id3_tag);
+
+GST_TAG_API
 const gchar *           gst_tag_from_id3_user_tag               (const gchar *          type,
                                                                  const gchar *          id3_user_tag);
+
+GST_TAG_API
 const gchar *           gst_tag_to_id3_tag                      (const gchar *          gst_tag);
 
+GST_TAG_API
 gboolean                gst_tag_list_add_id3_image (GstTagList   * tag_list,
                                                     const guint8 * image_data,
                                                     guint          image_data_len,
                                                     guint          id3_picture_type);
 
+GST_TAG_API
 GstTagList *            gst_tag_list_from_id3v2_tag (GstBuffer * buffer);
 
+GST_TAG_API
 guint                   gst_tag_get_id3v2_tag_size  (GstBuffer * buffer);
 
 /* functions to  convert GstBuffers with xmp packets contents to GstTagLists and back */
+
+GST_TAG_API
 GstTagList *            gst_tag_list_from_xmp_buffer (GstBuffer *  buffer);
+
+GST_TAG_API
 GstBuffer *		          gst_tag_list_to_xmp_buffer   (const GstTagList * list,
 							                                        gboolean read_only,
 							                                        const gchar ** schemas);
+
+GST_TAG_API
 const gchar**		        gst_tag_xmp_list_schemas     (void);
 
 /* functions related to exif */
+
+GST_TAG_API
 GstBuffer *             gst_tag_list_to_exif_buffer (const GstTagList * taglist,
                                                      gint byte_order,
                                                      guint32 base_offset);
 
+GST_TAG_API
 GstBuffer *             gst_tag_list_to_exif_buffer_with_tiff_header (const GstTagList * taglist);
 
+GST_TAG_API
 GstTagList *            gst_tag_list_from_exif_buffer (GstBuffer * buffer,
                                                        gint byte_order,
                                                        guint32 base_offset);
 
+GST_TAG_API
 GstTagList *            gst_tag_list_from_exif_buffer_with_tiff_header (
                                                       GstBuffer * buffer);
 
 /* other tag-related functions */
 
+GST_TAG_API
 gboolean                gst_tag_parse_extended_comment (const gchar  * ext_comment,
                                                         gchar       ** key,
                                                         gchar       ** lang,
                                                         gchar       ** value,
                                                         gboolean       fail_if_no_key);
 
+GST_TAG_API
 gchar                 * gst_tag_freeform_string_to_utf8 (const gchar  * data,
                                                          gint           size,
                                                          const gchar ** env_vars);
 
+GST_TAG_API
 GstSample             * gst_tag_image_data_to_image_sample (const guint8   * image_data,
                                                             guint            image_data_len,
                                                             GstTagImageType  image_type);
 
 /* FIXME 0.11: get rid of this awkward register/init function, see tags.c */
+
+GST_TAG_API
 void                    gst_tag_register_musicbrainz_tags (void);
 
 
 /* language tag related functions */
 
+GST_TAG_API
 gchar **       gst_tag_get_language_codes (void);
 
+GST_TAG_API
 const gchar *  gst_tag_get_language_name (const gchar * language_code);
 
+GST_TAG_API
 const gchar *  gst_tag_get_language_code_iso_639_1 (const gchar * lang_code);
 
+GST_TAG_API
 const gchar *  gst_tag_get_language_code_iso_639_2B (const gchar * lang_code);
 
+GST_TAG_API
 const gchar *  gst_tag_get_language_code_iso_639_2T (const gchar * lang_code);
 
+GST_TAG_API
 gboolean       gst_tag_check_language_code          (const gchar * lang_code);
 
 /**
@@ -570,22 +682,27 @@ typedef enum {
   GST_TAG_LICENSE_FREE_SOFTWARE_FOUNDATION_LICENSE = (1 << 25)
 } GstTagLicenseFlags;
 
+GST_TAG_API
 gchar **            gst_tag_get_licenses (void);
 
+GST_TAG_API
 GstTagLicenseFlags  gst_tag_get_license_flags (const gchar * license_ref);
 
+GST_TAG_API
 const gchar *       gst_tag_get_license_nick  (const gchar * license_ref);
 
+GST_TAG_API
 const gchar *       gst_tag_get_license_title (const gchar * license_ref);
 
+GST_TAG_API
 const gchar *       gst_tag_get_license_version (const gchar * license_ref);
 
+GST_TAG_API
 const gchar *       gst_tag_get_license_description  (const gchar * license_ref);
 
+GST_TAG_API
 const gchar *       gst_tag_get_license_jurisdiction (const gchar * license_ref);
 
-GType               gst_tag_license_flags_get_type (void);
-
 G_END_DECLS
 
 #endif /* __GST_TAG_TAG_H__ */
